==> jc-1.4.0.tar.gz: java/lang/NoSuchMethodException.h <==
// public class java.lang.NoSuchMethodException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 7b6084420f3560a5 java_lang_NoSuchMethodException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_NoSuchMethodException_H_
#define _JC_java_lang_NoSuchMethodException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_NoSuchMethodException$sub_refs	_jc_java_lang_NoSuchMethodException$sub_refs;
typedef struct _jc_java_lang_NoSuchMethodException$sub_nonrefs	_jc_java_lang_NoSuchMethodException$sub_nonrefs;
typedef struct _jc_java_lang_NoSuchMethodException$refs	_jc_java_lang_NoSuchMethodException$refs;
typedef struct _jc_java_lang_NoSuchMethodException$nonrefs	_jc_java_lang_NoSuchMethodException$nonrefs;
typedef struct _jc_java_lang_NoSuchMethodException$object	_jc_java_lang_NoSuchMethodException$object;

typedef struct _jc_java_lang_NoSuchMethodException$fields_struct	_jc_java_lang_NoSuchMethodException$fields_struct;
typedef const struct _jc_java_lang_NoSuchMethodException$vmethods	_jc_java_lang_NoSuchMethodException$vmethods;
typedef const struct _jc_java_lang_NoSuchMethodException$vtable	_jc_java_lang_NoSuchMethodException$vtable;
typedef const struct _jc_java_lang_NoSuchMethodException$vtype	_jc_java_lang_NoSuchMethodException$vtype;

// Class fields structure
struct _jc_java_lang_NoSuchMethodException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_NoSuchMethodException$fields_struct _jc_java_lang_NoSuchMethodException$class_fields;

// Constructors
extern void _jc_java_lang_NoSuchMethodException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_NoSuchMethodException$object *);
extern void _jc_java_lang_NoSuchMethodException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_NoSuchMethodException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_NoSuchMethodException$vmethods {
};

// Vtable
struct _jc_java_lang_NoSuchMethodException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_NoSuchMethodException$vmethods	java_lang_NoSuchMethodException;
};

// Vtype
struct _jc_java_lang_NoSuchMethodException$vtype {
	_jc_type			type;
	_jc_java_lang_NoSuchMethodException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_NoSuchMethodException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_NoSuchMethodException$refs {
    _jc_java_lang_NoSuchMethodException$sub_refs	java_lang_NoSuchMethodException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_NoSuchMethodException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_NoSuchMethodException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_NoSuchMethodException$sub_nonrefs	java_lang_NoSuchMethodException;
};

// Object instance structure
struct _jc_java_lang_NoSuchMethodException$object {
	_jc_java_lang_NoSuchMethodException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_NoSuchMethodException$vtype	*vtype;
	_jc_java_lang_NoSuchMethodException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_NoSuchMethodException$vtype _jc_java_lang_NoSuchMethodException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_NoSuchMethodException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_NoSuchMethodException$class_object;

#endif	/* _JC_java_lang_NoSuchMethodException_H_ */

==> jc-1.4.6.tar.gz: java/lang/NoSuchMethodException.h <==
// public class java.lang.NoSuchMethodException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 7b6084420f3560a5 java_lang_NoSuchMethodException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_NoSuchMethodException_H_
#define _JC_java_lang_NoSuchMethodException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_NoSuchMethodException$sub_refs	_jc_java_lang_NoSuchMethodException$sub_refs;
typedef struct _jc_java_lang_NoSuchMethodException$sub_nonrefs	_jc_java_lang_NoSuchMethodException$sub_nonrefs;
typedef struct _jc_java_lang_NoSuchMethodException$refs	_jc_java_lang_NoSuchMethodException$refs;
typedef struct _jc_java_lang_NoSuchMethodException$nonrefs	_jc_java_lang_NoSuchMethodException$nonrefs;
typedef struct _jc_java_lang_NoSuchMethodException$object	_jc_java_lang_NoSuchMethodException$object;

typedef struct _jc_java_lang_NoSuchMethodException$fields_struct	_jc_java_lang_NoSuchMethodException$fields_struct;
typedef const struct _jc_java_lang_NoSuchMethodException$vmethods	_jc_java_lang_NoSuchMethodException$vmethods;
typedef const struct _jc_java_lang_NoSuchMethodException$vtable	_jc_java_lang_NoSuchMethodException$vtable;
typedef const struct _jc_java_lang_NoSuchMethodException$vtype	_jc_java_lang_NoSuchMethodException$vtype;

// Class fields structure
struct _jc_java_lang_NoSuchMethodException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_NoSuchMethodException$fields_struct _jc_java_lang_NoSuchMethodException$class_fields;

// Constructors
extern void _jc_java_lang_NoSuchMethodException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_NoSuchMethodException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_NoSuchMethodException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_NoSuchMethodException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_NoSuchMethodException$vmethods {
};

// Vtable
struct _jc_java_lang_NoSuchMethodException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_NoSuchMethodException$vmethods	java_lang_NoSuchMethodException;
};

// Vtype
struct _jc_java_lang_NoSuchMethodException$vtype {
	_jc_type			type;
	_jc_java_lang_NoSuchMethodException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_NoSuchMethodException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_NoSuchMethodException$refs {
    _jc_java_lang_NoSuchMethodException$sub_refs	java_lang_NoSuchMethodException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_NoSuchMethodException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_NoSuchMethodException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_NoSuchMethodException$sub_nonrefs	java_lang_NoSuchMethodException;
};

// Object instance structure
struct _jc_java_lang_NoSuchMethodException$object {
	_jc_java_lang_NoSuchMethodException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_NoSuchMethodException$vtype	*vtype;
	_jc_java_lang_NoSuchMethodException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_NoSuchMethodException$vtype _jc_java_lang_NoSuchMethodException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_NoSuchMethodException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_NoSuchMethodException$class_object;

#endif	/* _JC_java_lang_NoSuchMethodException_H_ */
